Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(170)

Unified Diff: third_party/WebKit/public/platform/modules/presentation/WebPresentationAvailabilityObserver.h

Issue 2552343009: [Presentation API] Adds DOMString[] constructor to PresentationRequest. (Closed)
Patch Set: resolve code review comments from foolip Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/public/platform/modules/presentation/WebPresentationAvailabilityObserver.h
diff --git a/third_party/WebKit/public/platform/modules/presentation/WebPresentationAvailabilityObserver.h b/third_party/WebKit/public/platform/modules/presentation/WebPresentationAvailabilityObserver.h
index 40a53bde088752d8eab044e1abc8f0505389cdb7..8d3d7aa7f1b82e2a4d013250d177f3d7af73ddc2 100644
--- a/third_party/WebKit/public/platform/modules/presentation/WebPresentationAvailabilityObserver.h
+++ b/third_party/WebKit/public/platform/modules/presentation/WebPresentationAvailabilityObserver.h
@@ -10,16 +10,20 @@
namespace blink {
+class WebURL;
+template <typename T>
+class WebVector;
+
// WebPresentationAvailabilityObserver is an interface that is implemented by
// objects that wish to be notified when there is a presentation display
// availability change for a given URL.
class BLINK_PLATFORM_EXPORT WebPresentationAvailabilityObserver {
public:
virtual ~WebPresentationAvailabilityObserver() = default;
virtual void availabilityChanged(bool) = 0;
- virtual const WebURL url() const = 0;
+ virtual const WebVector<WebURL>& urls() const = 0;
};
} // namespace blink
@@ -10,16 +10,20 @@
// WebPresentationAvailabilityObserver is an interface that is implemented by
// objects that wish to be notified when there is a presentation display
-// availability change for a given URL.
+// availability change for given URLs.
class BLINK_PLATFORM_EXPORT WebPresentationAvailabilityObserver {
public:

Powered by Google App Engine
This is Rietveld 408576698